pub struct KeyValueFactorData(/* private fields */);Trait Implementations
Sourceimpl HasData for KeyValueFactorData
impl HasData for KeyValueFactorData
Sourcetype Data<'a> = &'a mut KeyValueDispatch
type Data<'a> = &'a mut KeyValueDispatch
The data associated with this trait implementation, chiefly used as a
generic associated type to allow plumbing the
'a lifetime into the
definition here. Read moreSourceimpl HostStoreWithStore for KeyValueFactorData
impl HostStoreWithStore for KeyValueFactorData
Sourceasync fn open<T>(
accessor: &Accessor<T, Self>,
label: String,
) -> Result<Resource<Store>, Error>
async fn open<T>( accessor: &Accessor<T, Self>, label: String, ) -> Result<Resource<Store>, Error>
Open the store with the specified label. Read more
Sourceasync fn get<T>(
accessor: &Accessor<T, Self>,
store: Resource<Store>,
key: String,
) -> Result<Option<Vec<u8>>, Error>
async fn get<T>( accessor: &Accessor<T, Self>, store: Resource<Store>, key: String, ) -> Result<Option<Vec<u8>>, Error>
Get the value associated with the specified
key Read moreSourceasync fn set<T>(
accessor: &Accessor<T, Self>,
store: Resource<Store>,
key: String,
value: Vec<u8>,
) -> Result<(), Error>
async fn set<T>( accessor: &Accessor<T, Self>, store: Resource<Store>, key: String, value: Vec<u8>, ) -> Result<(), Error>
Set the
value associated with the specified key overwriting any existing value.Sourceasync fn delete<T>(
accessor: &Accessor<T, Self>,
store: Resource<Store>,
key: String,
) -> Result<(), Error>
async fn delete<T>( accessor: &Accessor<T, Self>, store: Resource<Store>, key: String, ) -> Result<(), Error>
Delete the tuple with the specified
key Read moreAuto Trait Implementations
impl Freeze for KeyValueFactorData
impl RefUnwindSafe for KeyValueFactorData
impl Send for KeyValueFactorData
impl Sync for KeyValueFactorData
impl Unpin for KeyValueFactorData
impl UnsafeUnpin for KeyValueFactorData
impl UnwindSafe for KeyValueFactorData